@@ -15,6 +15,8 @@
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
 
+#include "config.h"
+
 #include "speaker.h"
 #include "speakerdb.h"
 #include "importexport.h"
@@ -45,6 +47,21 @@ MainWindow::MainWindow(QWidget *parent) :
 {
     ui->setupUi(this);
 
+    /* setup recently opened menu */
+    for (int i = 0; i < MaxRecentFiles; ++i) {
+        recentFileActs[i] = new QAction(this);
+        recentFileActs[i]->setVisible(false);
+        connect(recentFileActs[i], &QAction::triggered, this, &MainWindow::onOpenRecentActionTriggered);
+    }
+
+    QMenu* sub = new QMenu(tr("Recently opened"), ui->menuProject);
+    ui->menuProject->insertMenu(ui->actionProjectSave, sub);
+
+    for (int i = 0; i < MaxRecentFiles; ++i)
+        sub->addAction(recentFileActs[i]);
+
+    updateRecentFileActions();
+
     /* setup maximums of spinbox */
     ui->numberSpinBox->setMaximum(std::numeric_limits<int>::max());
     ui->sealedVolumeDoubleSpinBox->setMaximum(std::numeric_limits<double>::max());
@@ -98,8 +115,13 @@ MainWindow::MainWindow(QWidget *parent) :
     this->ui->actionRedo->setEnabled(false);
 
     /* restore last saved project... */
-    ImportExport::restoreProject(currentSpeaker, currentSealedBox, currentPortedBox, currentBandPassBox, &currentSpeakerNumber, &currentTabIndex);
-    projectSaved = true;
+    if (ImportExport::restoreProject(currentSpeaker, currentSealedBox, currentPortedBox, currentBandPassBox, &currentSpeakerNumber, &currentTabIndex))
+        projectSaved = true;
+    else {
+        projectSaved = false;
+        currentSpeakerNumber = 1;
+        currentTabIndex = 0;
+    }
 
     /* on first run, no speaker. reset to the speaker of the combos if needed */
     if (!currentSpeaker.isValid()) {
@@ -148,22 +170,38 @@ MainWindow::~MainWindow()
 
 void MainWindow::onProjectSave()
 {
-    projectSaved = true;
 
-    ImportExport::saveProject(currentSpeaker, currentSealedBox, currentPortedBox, currentBandPassBox, currentSpeakerNumber, currentTabIndex);
+    if(ImportExport::saveProject(currentSpeaker, currentSealedBox, currentPortedBox, currentBandPassBox, currentSpeakerNumber, currentTabIndex)) {
+        projectSaved = true;
+
+#if QT_VERSION >= QT_VERSION_CHECK(6,0,0)
+        QString prefix = QStandardPaths::writableLocation(QStandardPaths::AppLocalDataLocation);
+#elif QT_VERSION >= QT_VERSION_CHECK(5,0,0)
+        QString prefix = QStandardPaths::writableLocation(QStandardPaths::DataLocation);
+#else
+        QString prefix = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
+#endif
+        if (!ImportExport::getSavePath().startsWith(prefix))
+            setRecentFile(ImportExport::getSavePath(), true);
+    }
 }
 
 void MainWindow::onProjectExport()
 {
     QString home = MainWindow::getHome();
-    QString fileName = QFileDialog::getSaveFileName(this, tr("Export File"), home + tr("/untitled.qsp"), tr("QSpeakers project (*.qsp)"));
+    QString fileName = QFileDialog::getSaveFileName(this, tr("Export File"), home + QDir::separator() + tr("untitled.qsp"), tr("QSpeakers project (*.qsp)"));
 
     /* user cancelled */
     if (fileName.isEmpty())
         return;
 
+    if (!fileName.endsWith(".qsp"))
+        fileName += ".qsp";
+
     QFile file(fileName);
-    ImportExport::exportProject(file, currentSpeaker, currentSealedBox, currentPortedBox, currentBandPassBox, currentSpeakerNumber, currentTabIndex);
+    if(ImportExport::exportProject(file, currentSpeaker, currentSealedBox, currentPortedBox, currentBandPassBox, currentSpeakerNumber, currentTabIndex)) {
+        setRecentFile(fileName, true);
+    }
 }
 
 void MainWindow::onProjectImport()
@@ -184,6 +222,62 @@ void MainWindow::onProjectImport()
     if (fileName.isEmpty())
         return;
 
+    if (!loadFile(fileName)) {
+        QMessageBox::warning(this, tr("Warning"), tr("Could not open project!"));
+    }
+}
+
+void MainWindow::onOpenRecentActionTriggered()
+{
+    QAction *action = qobject_cast<QAction *>(sender());
+    if (action) {
+        if (!loadFile(action->data().toString())) {
+            QMessageBox::warning(this, tr("Warning"), tr("Could not open project!"));
+        }
+    }
+}
+
+QString MainWindow::strippedName(const QString& fullFileName)
+{
+    return QFileInfo(fullFileName).fileName();
+}
+
+void MainWindow::updateRecentFileActions()
+{
+    QSettings settings(SETTINGS_DOMAIN, SETTINGS_APP);
+    QStringList files = settings.value("recentFileList").toStringList();
+
+    int numRecentFiles = qMin(files.size(), (int)MaxRecentFiles);
+
+    for (int i = 0; i < numRecentFiles; ++i) {
+        QString text = tr("&%1 %2").arg(i + 1).arg(strippedName(files[i]));
+        recentFileActs[i]->setText(text);
+        recentFileActs[i]->setData(files[i]);
+        recentFileActs[i]->setVisible(true);
+    }
+
+    for (int j = numRecentFiles; j < MaxRecentFiles; ++j)
+        recentFileActs[j]->setVisible(false);
+}
+
+void MainWindow::setRecentFile(const QString& fileName, bool ok)
+{
+    QSettings settings(SETTINGS_DOMAIN, SETTINGS_APP);
+    QStringList files = settings.value("recentFileList").toStringList();
+    files.removeAll(fileName);
+
+    if (ok)
+        files.prepend(fileName);
+
+    while (files.size() > MaxRecentFiles)
+        files.removeLast();
+
+    settings.setValue("recentFileList", files);
+    updateRecentFileActions();
+}
+
+bool MainWindow::loadFile(const QString& fileName)
+{
     /* clear undo history */
     this->commandStack->clear();
 
@@ -191,7 +285,17 @@ void MainWindow::onProjectImport()
     unlinkTabs();
 
     QFile file(fileName);
-    ImportExport::importProject(currentSpeaker, currentSealedBox, currentPortedBox, currentBandPassBox, &currentSpeakerNumber, &currentTabIndex, file);
+    if (!ImportExport::importProject(currentSpeaker, currentSealedBox, currentPortedBox, currentBandPassBox, &currentSpeakerNumber, &currentTabIndex, file)) {
+        setRecentFile(fileName, false);
+
+        linkInternals();
+        linkTabs();
+
+        return false;
+    }
+
+    setRecentFile(fileName, true);
+
     ImportExport::setSavePath(fileName);
     setWindowFilePath(ImportExport::getSavePath());
 
@@ -207,6 +311,8 @@ void MainWindow::onProjectImport()
 
     if (notInDbSpeaker)
         onSpeakerModify();
+
+    return true;
 }
 
 void MainWindow::onProjectQuit()
@@ -537,9 +643,9 @@ void MainWindow::exportPlot(const QString& outfileName, int tabindex)
 }
 
 /* FIXME: should be taken from a popup before to export */
-#define MARGIN 5 /* cm */
-#define WOODTHICK 2 /* cm */
-#define SAWTHICK 0.1 /* cm */
+#define MARGIN 50 /* mm */
+#define WOODTHICK 20 /* mm */
+#define SAWTHICK 1 /* mm */
 
 void MainWindow::exportScad(const QString& scad, const QString &outfileName, int tabindex)
 {
@@ -550,7 +656,7 @@ void MainWindow::exportScad(const QString& scad, const QString &outfileName, int
     s.replace("__MODEL__", currentSpeaker.getModel());
     s.replace("__NUMBER__", QString::number(currentSpeakerNumber));
     s.replace("__MARGIN__", QString::number(MARGIN));
-    s.replace("__DIAMETER__", QString::number(currentSpeaker.getDia() * 100));
+    s.replace("__DIAMETER__", QString::number(currentSpeaker.getDia() * 1000)); /* mm */
     s.replace("__WOODTHICK__", QString::number(WOODTHICK));
     s.replace("__SAWTHICK__", QString::number(SAWTHICK));
     if (tabindex == 0) {
@@ -562,26 +668,32 @@ void MainWindow::exportScad(const QString& scad, const QString &outfileName, int
         s.replace("__SEALEDBOXVOLUME__", QString::number(currentBandPassBox.getSealedBoxVolume()));
         s.replace("__PORTEDBOXVOLUME__", QString::number(currentBandPassBox.getPortedBoxVolume()));
         s.replace("__PORTEDBOXPORTNUMBER__", QString::number(currentBandPassBox.getPortedBoxPortNum()));
-        s.replace("__PORTEDBOXPORTSLOTWIDTH__", "0"); /* not supported yet */
-        s.replace("__PORTEDBOXPORTSLOTHEIGHT__", "0"); /* not supported yet */
     }
 
     if (tabindex == 1) {
         if (currentPortedBox.getSlotPortActivated()) {
             s.replace("__PORTEDBOXPORTSLOTACTIVATED__", "true");
-            s.replace("__PORTEDBOXPORTSLOTWIDTH__", QString::number(currentPortedBox.getSlotWidth()));
-            s.replace("__PORTEDBOXPORTSLOTHEIGHT__", QString::number(currentPortedBox.getSlotHeight()));
+            s.replace("__PORTEDBOXPORTSLOTWIDTH__", QString::number(currentPortedBox.getSlotWidth() * 10)); /* mm */
+            s.replace("__PORTEDBOXPORTSLOTHEIGHT__", QString::number(currentPortedBox.getSlotHeight() * 10)); /* mm */
         } else {
             s.replace("__PORTEDBOXPORTSLOTACTIVATED__", "false");
             s.replace("__PORTEDBOXPORTSLOTWIDTH__", "0");
             s.replace("__PORTEDBOXPORTSLOTHEIGHT__", "0");
         }
-        s.replace("__PORTEDBOXPORTDIAMETER__", QString::number(currentPortedBox.getPortDiam()));
-        s.replace("__PORTEDBOXPORTLENGTH__", QString::number(currentPortedBox.getPortLen()));
+        s.replace("__PORTEDBOXPORTDIAMETER__", QString::number(currentPortedBox.getPortDiam() * 10)); /* mm */
+        s.replace("__PORTEDBOXPORTLENGTH__", QString::number(currentPortedBox.getPortLen() * 10)); /* mm */
     } else if (tabindex == 2) {
-        s.replace("__PORTEDBOXPORTSLOTACTIVATED__", "false");
-        s.replace("__PORTEDBOXPORTDIAMETER__", QString::number(currentBandPassBox.getPortedBoxPortDiam()));
-        s.replace("__PORTEDBOXPORTLENGTH__", QString::number(currentBandPassBox.getPortedBoxPortLen()));
+        if (currentBandPassBox.getPortedBoxSlotPortActivated()) {
+            s.replace("__PORTEDBOXPORTSLOTACTIVATED__", "true");
+            s.replace("__PORTEDBOXPORTSLOTWIDTH__", QString::number(currentBandPassBox.getPortedBoxSlotWidth() * 10)); /* mm */
+            s.replace("__PORTEDBOXPORTSLOTHEIGHT__", QString::number(currentBandPassBox.getPortedBoxSlotHeight() * 10)); /* mm */
+        } else {
+            s.replace("__PORTEDBOXPORTSLOTACTIVATED__", "false");
+            s.replace("__PORTEDBOXPORTSLOTWIDTH__", "0");
+            s.replace("__PORTEDBOXPORTSLOTHEIGHT__", "0");
+        }
+        s.replace("__PORTEDBOXPORTDIAMETER__", QString::number(currentBandPassBox.getPortedBoxPortDiam() * 10)); /* mm */
+        s.replace("__PORTEDBOXPORTLENGTH__", QString::number(currentBandPassBox.getPortedBoxPortLen() * 10)); /* mm */
     }
 
     QFile f(outfileName);
@@ -618,7 +730,7 @@ void MainWindow::exportScad3D(const QString &outfileName, int tabindex)
         break;
     case 2: /* bandpass box */
         /* non-prod version: */
-        scad = "../qpseakers/bandpassbox_template.scad";
+        scad = "../qspeakers/bandpassbox_template.scad";
         if (!QFileInfo::exists(scad))
 #ifdef __mswin
             scad = (QCoreApplication::applicationDirPath() + QDir::separator() + "sealedbox_template.scad");
@@ -642,7 +754,7 @@ void MainWindow::exportScad2D(const QString &outfileName, int tabindex)
     switch (tabindex) {
     case 0: /* closed box */
         /* non-prod version: */
-        scad = "../qpseakers/sealedbox_cutting_template.scad";
+        scad = "../qspeakers/sealedbox_cutting_template.scad";
         if (!QFileInfo::exists(scad))
 #ifdef __mswin
             scad = (QCoreApplication::applicationDirPath() + QDir::separator() + "sealedbox_cutting_template.scad");
@@ -652,7 +764,7 @@ void MainWindow::exportScad2D(const QString &outfileName, int tabindex)
         break;
     case 1: /* vented box */
         /* non-prod version: */
-        scad = "../qpseakers/portedbox_cutting_template.scad";
+        scad = "../qspeakers/portedbox_cutting_template.scad";
         if (!QFileInfo::exists(scad))
 #ifdef __mswin
             scad = (QCoreApplication::applicationDirPath() + QDir::separator() + "sealedbox_cutting_template.scad");
@@ -662,7 +774,7 @@ void MainWindow::exportScad2D(const QString &outfileName, int tabindex)
         break;
     case 2: /* bandpass box */
         /* non-prod version: */
-        scad = "../qpseakers/bandpassbox_cutting_template.scad";
+        scad = "../qspeakers/bandpassbox_cutting_template.scad";
         if (!QFileInfo::exists(scad))
 #ifdef __mswin
             scad = (QCoreApplication::applicationDirPath() + QDir::separator() + "sealedbox_cutting_template.scad");
@@ -1009,7 +1121,7 @@ void MainWindow::onAboutAbout()
                        tr("QSpeakers version " VERSION "\n\n"
                                                        "This program simulates common acoustical enclosures behaviour to help designing loudspeaker systems.\n\n"
                                                        "This program is free software, copyright (C) 2014 Benoit Rouits <brouits@free.fr> and released under the GNU General Public Lisence "
-                                                       "version 3. It is delivered as is in the hope it can be useful, but with no warranty of correctness."));
+                                                       "version 3. It is delivered as is in the hope it can be useful, but with no warranty at all."));
 }
 
 void MainWindow::onSearchRequested(const QString& param, double min, double max)
