@@ -25,585 +25,633 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="mainwindow.ui" line="30"/>
+        <location filename="mainwindow.ui" line="24"/>
         <source>Loudspeaker</source>
         <translation>Haut-parleur</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="36"/>
+        <location filename="mainwindow.ui" line="30"/>
         <source>number</source>
         <translation>nombre</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="53"/>
+        <location filename="mainwindow.ui" line="56"/>
         <source>vendor</source>
         <translation>constructeur</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="70"/>
+        <location filename="mainwindow.ui" line="73"/>
         <source>model</source>
         <translation>modèle</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="106"/>
-        <source>Fs</source>
-        <translation>Fs</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="113"/>
-        <location filename="mainwindow.ui" line="153"/>
+        <location filename="mainwindow.ui" line="115"/>
+        <location filename="mainwindow.ui" line="141"/>
+        <location filename="mainwindow.ui" line="167"/>
         <location filename="mainwindow.ui" line="186"/>
-        <location filename="mainwindow.ui" line="226"/>
-        <location filename="mainwindow.ui" line="266"/>
+        <location filename="mainwindow.ui" line="212"/>
+        <location filename="mainwindow.ui" line="238"/>
         <source>0</source>
         <translation>0</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="120"/>
-        <location filename="mainwindow.ui" line="502"/>
-        <location filename="mainwindow.ui" line="822"/>
+        <location filename="mainwindow.ui" line="148"/>
+        <location filename="mainwindow.ui" line="448"/>
+        <location filename="mainwindow.ui" line="768"/>
         <source>Hz</source>
         <translation>Hz</translation>
     </message>
-    <message>
-        <location filename="mainwindow.ui" line="146"/>
-        <source>Qts</source>
-        <translation>Qts</translation>
-    </message>
     <message>
         <location filename="mainwindow.ui" line="179"/>
-        <source>Vas</source>
-        <translation>Vas</translation>
+        <source>Vas:</source>
+        <oldsource>Vas</oldsource>
+        <translation>Vas :</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="193"/>
-        <location filename="mainwindow.ui" line="378"/>
-        <location filename="mainwindow.ui" line="465"/>
-        <location filename="mainwindow.ui" line="728"/>
-        <location filename="mainwindow.ui" line="785"/>
+        <location filename="mainwindow.ui" line="327"/>
+        <location filename="mainwindow.ui" line="411"/>
+        <location filename="mainwindow.ui" line="677"/>
+        <location filename="mainwindow.ui" line="731"/>
         <source>L</source>
         <translation>L</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="233"/>
+        <location filename="mainwindow.ui" line="219"/>
         <source>m</source>
         <translation>m</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="273"/>
+        <location filename="mainwindow.ui" line="245"/>
         <source>Ohm</source>
         <translation>Ohm</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="299"/>
-        <source>Vc</source>
-        <translation>Vc</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="306"/>
+        <location filename="mainwindow.ui" line="264"/>
         <source>1</source>
         <translation>1</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="326"/>
+        <location filename="mainwindow.ui" line="278"/>
         <source>Sealed enclosure</source>
         <translation>Enceinte close</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="329"/>
+        <location filename="mainwindow.ui" line="281"/>
         <source>1st order filter</source>
         <translation>filtre du premier ordre</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="332"/>
+        <location filename="mainwindow.ui" line="284"/>
         <source>Simple, safe enclosure good for several speakers.</source>
         <translation>Enceinte simple et sûre, bonne pour certains haut-parleurs.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="361"/>
+        <location filename="mainwindow.ui" line="313"/>
         <source>Enclosure volume</source>
         <translation>Volume de l&apos;enceinte</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="416"/>
+        <location filename="mainwindow.ui" line="365"/>
         <source>Ported enclosure</source>
         <translation>Enceinte à évent</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="419"/>
+        <location filename="mainwindow.ui" line="368"/>
         <source>2nd order filter</source>
         <translation>filtre du second ordre</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="422"/>
+        <location filename="mainwindow.ui" line="371"/>
         <source>Popular enclosure type to enhance bass for most speakers.</source>
         <translation>Type d&apos;enceinte réputé pour améliorer la réponse en basses pour la plupart des haut-parleurs.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="448"/>
+        <location filename="mainwindow.ui" line="397"/>
         <source>Enclosure volume (Vb)</source>
         <translation>Volume de l&apos;enceinte (Vb)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="485"/>
+        <location filename="mainwindow.ui" line="431"/>
         <source>Enclosure filter resonance (Fb)</source>
         <translation>Résonnance de l&apos;enceinte (Fb)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="536"/>
-        <location filename="mainwindow.ui" line="856"/>
+        <location filename="mainwindow.ui" line="482"/>
+        <location filename="mainwindow.ui" line="802"/>
         <source>Number of ports</source>
         <translation>Nombre d&apos;évents</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="553"/>
-        <location filename="mainwindow.ui" line="873"/>
+        <location filename="mainwindow.ui" line="499"/>
+        <location filename="mainwindow.ui" line="819"/>
         <source>Port diameter</source>
         <translation>Diamètre d&apos;évent</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="567"/>
-        <location filename="mainwindow.ui" line="627"/>
-        <location filename="mainwindow.ui" line="667"/>
-        <location filename="mainwindow.ui" line="887"/>
-        <location filename="mainwindow.ui" line="927"/>
+        <location filename="mainwindow.ui" line="516"/>
+        <location filename="mainwindow.ui" line="579"/>
+        <location filename="mainwindow.ui" line="619"/>
+        <location filename="mainwindow.ui" line="836"/>
+        <location filename="mainwindow.ui" line="879"/>
+        <location filename="mainwindow.ui" line="919"/>
         <source>cm</source>
         <translation>cm</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="587"/>
+        <location filename="mainwindow.ui" line="536"/>
+        <location filename="mainwindow.ui" line="856"/>
         <source>Slot port</source>
         <translation>Laminaire</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="604"/>
+        <location filename="mainwindow.ui" line="556"/>
+        <location filename="mainwindow.ui" line="869"/>
         <source>x</source>
         <translatorcomment>multiply sign</translatorcomment>
         <translation>x</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="647"/>
-        <location filename="mainwindow.ui" line="907"/>
+        <location filename="mainwindow.ui" line="599"/>
+        <location filename="mainwindow.ui" line="899"/>
         <source>Port length</source>
         <translation>Longueur d&apos;évent</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="679"/>
+        <location filename="mainwindow.ui" line="631"/>
         <source>Bandpass enclosure</source>
         <translation>Caisson de basse</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="682"/>
+        <location filename="mainwindow.ui" line="634"/>
         <source>4th order filter</source>
         <translation>filtre du quatrième ordre</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="685"/>
+        <location filename="mainwindow.ui" line="637"/>
         <source>Enclosure for subwoofer, mostly used in 2:1, 5:1 and 7:1 systems.</source>
         <translation>Enceinte pour subwoofer, souvent utilisée pour les systèmes 2:1, 5:1 et 7:1.</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="711"/>
+        <location filename="mainwindow.ui" line="663"/>
         <source>Sealed enclosure volume</source>
         <translation>Volume de l&apos;enceinte close</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="768"/>
+        <location filename="mainwindow.ui" line="717"/>
         <source>Ported enclosure volume</source>
         <translation>Volume de l&apos;enceinte à évent</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="805"/>
+        <location filename="mainwindow.ui" line="751"/>
         <source>Ported enclosure filter resonance</source>
         <translation>Résonnance de l&apos;enceinte à évent</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="952"/>
+        <location filename="mainwindow.ui" line="944"/>
         <source>Project</source>
         <translation>Projet</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="964"/>
+        <location filename="mainwindow.ui" line="956"/>
         <source>Edit</source>
         <translation>Éditer</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="968"/>
+        <location filename="mainwindow.ui" line="960"/>
         <source>Ported alignments</source>
         <translation>Alignements avec évent</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="985"/>
+        <location filename="mainwindow.ui" line="977"/>
         <source>About</source>
         <translation>À propos</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="991"/>
+        <location filename="mainwindow.ui" line="983"/>
         <source>Speaker</source>
         <translation>Haut-parleur</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1000"/>
+        <location filename="mainwindow.ui" line="992"/>
         <source>Exports</source>
         <translation>Exports</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1039"/>
+        <location filename="mainwindow.ui" line="1031"/>
         <source>Ctrl+I</source>
         <translation>Ctrl+I</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1044"/>
+        <location filename="mainwindow.ui" line="1036"/>
         <source>Save</source>
         <translation>Enregistrer</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1050"/>
+        <location filename="mainwindow.ui" line="1042"/>
         <source>Ctrl+S</source>
         <translation>Ctrl+S</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1061"/>
+        <location filename="mainwindow.ui" line="1053"/>
         <source>Ctrl+E</source>
         <translation>Ctrl+E</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1066"/>
+        <location filename="mainwindow.ui" line="1058"/>
         <source>Print</source>
         <translation>Imprimer</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1069"/>
+        <location filename="mainwindow.ui" line="1061"/>
         <source>Print the current project</source>
         <translation>Imprime le projet</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1072"/>
+        <location filename="mainwindow.ui" line="1064"/>
         <source>Ctrl+P</source>
         <translation>Ctrl+P</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1077"/>
+        <location filename="mainwindow.ui" line="1069"/>
         <source>Quit</source>
         <translation>Quitter</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1080"/>
+        <location filename="mainwindow.ui" line="1072"/>
         <source>Quit the application</source>
         <translation>Quitte l&apos;application</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1083"/>
+        <location filename="mainwindow.ui" line="1075"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1088"/>
-        <location filename="mainwindow.cpp" line="890"/>
+        <location filename="mainwindow.ui" line="1080"/>
+        <location filename="mainwindow.cpp" line="1109"/>
         <source>About QSpeakers</source>
         <translation>À propos de QSpeakers</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1091"/>
+        <location filename="mainwindow.ui" line="1083"/>
         <source>Ctrl+A</source>
         <translation>Ctrl+A</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1096"/>
+        <location filename="mainwindow.ui" line="1088"/>
         <source>New</source>
         <translation>Nouveau</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1099"/>
+        <location filename="mainwindow.ui" line="1091"/>
         <source>New speaker parameters</source>
         <translation>Nouveau haut-parleur</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1102"/>
+        <location filename="mainwindow.ui" line="1094"/>
         <source>Ctrl+N</source>
         <translation>Ctrl+N</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1107"/>
+        <location filename="mainwindow.ui" line="1099"/>
         <source>Search</source>
         <translation>Rechercher</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1110"/>
+        <location filename="mainwindow.ui" line="1102"/>
         <source>Search a speaker</source>
         <translation>Recherche un haut-parleur</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1115"/>
+        <location filename="mainwindow.ui" line="1107"/>
         <source>Optimize</source>
         <translation>Optimiser</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1118"/>
+        <location filename="mainwindow.ui" line="1110"/>
         <source>Optimize frequency response</source>
         <translation>Optimise la réponse en fréquence</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1121"/>
+        <location filename="mainwindow.ui" line="1113"/>
         <source>Ctrl+O</source>
         <translation>Ctrl+O</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1126"/>
+        <location filename="mainwindow.ui" line="1118"/>
         <source>Modify</source>
         <translation>Modifier</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1129"/>
+        <location filename="mainwindow.ui" line="1121"/>
         <source>Modify the current speaker</source>
         <translation>Modifie le haut-parleur</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1132"/>
+        <location filename="mainwindow.ui" line="1124"/>
         <source>Ctrl+M</source>
         <translation>Ctrl+M</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1137"/>
+        <location filename="mainwindow.ui" line="1129"/>
         <source>Remove</source>
         <translation>Retirer</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1140"/>
+        <location filename="mainwindow.ui" line="1132"/>
         <source>Remove the current speaker</source>
         <translation>Retire le haut-parleur</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1145"/>
+        <location filename="mainwindow.ui" line="1137"/>
         <source>Bessel</source>
         <translation>Bessel</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1148"/>
+        <location filename="mainwindow.ui" line="1140"/>
         <source>Linear phase and fast transient response alignment</source>
         <translation>Alignement à phase linéaire et réponse en transitoire rapide</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1156"/>
+        <location filename="mainwindow.ui" line="1148"/>
         <source>Extended bass response with minimum ripple</source>
         <translation>Réponse étendue en grave avec un minimum d&apos;oscillation</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1164"/>
+        <location filename="mainwindow.ui" line="1156"/>
         <source>Boom box butterworth 4th order alignment</source>
         <translation>Alignement Butterworth du 4è ordre «Boom box»</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1172"/>
+        <location filename="mainwindow.ui" line="1164"/>
         <source>Super boom box butterworth 4th order alignment</source>
         <translation>Alignement Butterworth du 4è ordre «Super boom box»</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1194"/>
+        <location filename="mainwindow.ui" line="1186"/>
         <source>Undo</source>
         <translation>Défaire</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1197"/>
+        <location filename="mainwindow.ui" line="1189"/>
         <source>Undo action</source>
         <translation>Défaire</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1200"/>
+        <location filename="mainwindow.ui" line="1192"/>
         <source>Ctrl+U</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1209"/>
+        <location filename="mainwindow.ui" line="1201"/>
         <source>Redo</source>
         <translation>Refaire</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1212"/>
+        <location filename="mainwindow.ui" line="1204"/>
         <source>Redo action</source>
         <translation>Refaire</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1215"/>
+        <location filename="mainwindow.ui" line="1207"/>
         <source>Ctrl+R</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1220"/>
+        <location filename="mainwindow.ui" line="1212"/>
         <source>3D OpenScad</source>
         <translation>OpenScad 3D</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1225"/>
+        <location filename="mainwindow.ui" line="1217"/>
         <source>2D OpenScad</source>
         <translation>OpenScad 2D</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1230"/>
+        <location filename="mainwindow.ui" line="1222"/>
         <source>Curve Plot</source>
         <translation>Courbe</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1177"/>
+        <location filename="mainwindow.ui" line="1227"/>
+        <source>Open recent</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1169"/>
         <source>Zbinden M4</source>
         <translation>M4 Zbinden</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1180"/>
+        <location filename="mainwindow.ui" line="108"/>
+        <source>Spl:</source>
+        <translation>Spl :</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="122"/>
+        <source>dB</source>
+        <translation>dB</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="134"/>
+        <source>Fs:</source>
+        <translation>Fs :</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="160"/>
+        <source>Qts:</source>
+        <translation>Qts :</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="205"/>
+        <source>Dia:</source>
+        <translation>Dia :</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="231"/>
+        <source>Z:</source>
+        <translation>Z :</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="257"/>
+        <source>Vc:</source>
+        <translation>Vc :</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.ui" line="1172"/>
         <source>Moderate alignment (infinite baffle)</source>
         <translation>Alignement modéré (sur baffle infini)</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1185"/>
+        <location filename="mainwindow.ui" line="1177"/>
         <source>Bandpass alignment</source>
         <translation>Alignement caisson de basse</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1153"/>
+        <location filename="mainwindow.ui" line="1145"/>
         <source>Legendre</source>
         <translation>Legendre</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1033"/>
+        <location filename="mainwindow.ui" line="1025"/>
         <source>Open...</source>
         <translation>Ouvrir...</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="219"/>
-        <source>Dia</source>
-        <translation>Dia</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="259"/>
-        <source>Z</source>
-        <translation>Z</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.ui" line="1036"/>
+        <location filename="mainwindow.ui" line="1028"/>
         <source>Open a speaker project</source>
         <translation>Ouvre un projet</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1047"/>
+        <location filename="mainwindow.ui" line="1039"/>
         <source>Save the current project</source>
         <translation>Enregistre le projet</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1055"/>
+        <location filename="mainwindow.ui" line="1047"/>
         <source>Save copy...</source>
         <translation>Enregistrer une copie...</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1058"/>
+        <location filename="mainwindow.ui" line="1050"/>
         <source>Save the current project in a copy</source>
         <translation>Enregistre une copie du projet</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1161"/>
+        <location filename="mainwindow.ui" line="1153"/>
         <source>Hoge BB4</source>
         <translation>BB4 Hoge</translation>
     </message>
     <message>
-        <location filename="mainwindow.ui" line="1169"/>
+        <location filename="mainwindow.ui" line="1161"/>
         <source>Bullock SBB4</source>
         <translation>SBB4 Bullock</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="51"/>
+        <location filename="mainwindow.cpp" line="57"/>
+        <source>Recently opened</source>
+        <translation>Récemment ouvert</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="84"/>
         <source>Sealed volume frequency response</source>
         <translation>Réponse fréquentielle de l&apos;enceinte close</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="56"/>
+        <location filename="mainwindow.cpp" line="90"/>
         <source>Ported volume frequency response</source>
         <translation>Réponse fréquentielle de l&apos;enceinte à évent</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="61"/>
+        <location filename="mainwindow.cpp" line="96"/>
         <source>Bandpass volumes frequency response</source>
         <translation>Réponse fréquentielle du caisson de basse</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="140"/>
+        <location filename="mainwindow.cpp" line="187"/>
         <source>Export File</source>
         <translation>Exporter le fichier</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="140"/>
-        <source>/untitled.qsp</source>
-        <translation>/sans nom.qsp</translation>
-    </message>
-    <message>
-        <location filename="mainwindow.cpp" line="140"/>
-        <location filename="mainwindow.cpp" line="158"/>
+        <location filename="mainwindow.cpp" line="187"/>
+        <location filename="mainwindow.cpp" line="214"/>
         <source>QSpeakers project (*.qsp)</source>
         <translation>Projet QSpeakers (*.qsp)</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="150"/>
-        <location filename="mainwindow.cpp" line="202"/>
+        <location filename="mainwindow.cpp" line="187"/>
+        <source>untitled.qsp</source>
+        <translation>sans_nom.qsp</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="206"/>
+        <location filename="mainwindow.cpp" line="326"/>
         <source>Project not saved</source>
         <translation>Projet non enregistré</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="151"/>
+        <location filename="mainwindow.cpp" line="207"/>
         <source>The current project has not been saved. Continue anyway?</source>
         <translation>Le.projet actuel n&apos;a pas été enregistré. Continuer malgré tout ?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="158"/>
+        <location filename="mainwindow.cpp" line="214"/>
         <source>Import File</source>
         <translation>Importer un fichier</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="203"/>
+        <location filename="mainwindow.cpp" line="221"/>
+        <location filename="mainwindow.cpp" line="230"/>
+        <source>Warning</source>
+        <translation>Attention</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="221"/>
+        <location filename="mainwindow.cpp" line="230"/>
+        <source>Could not open project!</source>
+        <translation>Impossible d&apos;ouvrir le projet !</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="248"/>
+        <source>&amp;%1 %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="327"/>
         <source>The current project has not been saved. Exit anyway?</source>
         <translation>Le projet actuel n&apos;a pas été enregistré. Quitter malgré tout ?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="425"/>
+        <location filename="mainwindow.cpp" line="561"/>
         <source>Export for Gnuplot</source>
         <translation>Exporter pour Gnuplot</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="425"/>
+        <location filename="mainwindow.cpp" line="561"/>
         <source>Gnuplot data (*.dat)</source>
         <translation>Données Gnuplot (*.dat)</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="434"/>
+        <location filename="mainwindow.cpp" line="576"/>
         <source>Export for 3D OpenSCAD</source>
         <translation>Export 3D pour OpenSCAD</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="434"/>
+        <location filename="mainwindow.cpp" line="576"/>
+        <location filename="mainwindow.cpp" line="591"/>
         <source>OpenSCAD script (*.scad)</source>
         <translation>Script OpenSCAD (*.scad)</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="709"/>
+        <location filename="mainwindow.cpp" line="591"/>
+        <source>Export for 2D OpenSCAD</source>
+        <translation>Export 2D pour OpenSCAD</translation>
+    </message>
+    <message>
+        <location filename="mainwindow.cpp" line="928"/>
         <source>Removal confirmation</source>
         <translation>Confirmation de la suppression</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="710"/>
+        <location filename="mainwindow.cpp" line="929"/>
         <source>Do you really want to remove this loudspeaker from the database?</source>
         <translation>Voulez-vous vraiment retirer ce haut-parleur de la base de données ?</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="891"/>
+        <location filename="mainwindow.cpp" line="1110"/>
         <source>QSpeakers version </source>
         <translation>QSpeakers version </translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1027"/>
-        <location filename="mainwindow.cpp" line="1084"/>
+        <location filename="mainwindow.cpp" line="1246"/>
+        <location filename="mainwindow.cpp" line="1303"/>
         <source>Unsaved speaker</source>
         <translation>Haut-parleur non enregistré</translation>
     </message>
     <message>
-        <location filename="mainwindow.cpp" line="1028"/>
-        <location filename="mainwindow.cpp" line="1085"/>
+        <location filename="mainwindow.cpp" line="1247"/>
+        <location filename="mainwindow.cpp" line="1304"/>
         <source>This speaker is not present in the database. Would you like to insert it before to continue?</source>
         <translation>Ce haut-parleur n&apos;est pas présent dans la base de données. Voulez-vous l&apos;insérer avant de continuer ?</translation>
     </message>
@@ -611,19 +659,19 @@
 <context>
     <name>Plot</name>
     <message>
-        <location filename="plot.cpp" line="204"/>
+        <location filename="plot.cpp" line="250"/>
         <source>Frequency [Hz]</source>
         <translation>Fréquence [Hz]</translation>
     </message>
     <message>
-        <location filename="plot.cpp" line="212"/>
+        <location filename="plot.cpp" line="258"/>
         <source>Sound pressure [dB]</source>
         <translation>Pression sonore [dB]</translation>
     </message>
     <message>
-        <location filename="plot.cpp" line="95"/>
-        <location filename="plot.cpp" line="113"/>
-        <location filename="plot.cpp" line="126"/>
+        <location filename="plot.cpp" line="96"/>
+        <location filename="plot.cpp" line="128"/>
+        <location filename="plot.cpp" line="147"/>
         <source>%1 dB at %2 Hz</source>
         <translation>%1 dB à %2 Hz</translation>
     </message>
@@ -631,35 +679,35 @@
 <context>
     <name>QObject</name>
     <message>
-        <location filename="bandpassbox.cpp" line="123"/>
+        <location filename="bandpassbox.cpp" line="153"/>
         <source>Sealed Vol. %1 L</source>
         <translation>Vol. Clos %1 L</translation>
     </message>
     <message>
-        <location filename="bandpassbox.cpp" line="124"/>
+        <location filename="bandpassbox.cpp" line="154"/>
         <source>Ported Vol. %1 L</source>
         <translation>Vol. avec évent %1 L</translation>
     </message>
     <message>
-        <location filename="bandpassbox.cpp" line="125"/>
+        <location filename="bandpassbox.cpp" line="157"/>
         <location filename="portedbox.cpp" line="197"/>
         <source>Port Diam. %1 cm</source>
         <translation>Diam. Évent %1 cm</translation>
     </message>
     <message>
-        <location filename="bandpassbox.cpp" line="126"/>
+        <location filename="bandpassbox.cpp" line="162"/>
         <location filename="portedbox.cpp" line="201"/>
         <source>Port Len. %1 cm</source>
         <translation>Long. Évent %1 cm</translation>
     </message>
     <message>
-        <location filename="bandpassbox.cpp" line="127"/>
+        <location filename="bandpassbox.cpp" line="163"/>
         <location filename="portedbox.cpp" line="202"/>
         <source>Port Num. %1</source>
         <translation>Nombre Évent %1</translation>
     </message>
     <message>
-        <location filename="bandpassbox.cpp" line="128"/>
+        <location filename="bandpassbox.cpp" line="164"/>
         <location filename="portedbox.cpp" line="203"/>
         <source>Fb %1 Hz</source>
         <translation>Fb %1 Hz</translation>
@@ -671,6 +719,7 @@
         <translation>Vol. %1 L</translation>
     </message>
     <message>
+        <location filename="bandpassbox.cpp" line="159"/>
         <location filename="portedbox.cpp" line="199"/>
         <source>Slot port %1 x %2 cm</source>
         <translation>Évent laminaire %1 x %2 cm</translation>
@@ -840,7 +889,7 @@
 <context>
     <name>main</name>
     <message>
-        <location filename="main.cpp" line="37"/>
+        <location filename="main.cpp" line="44"/>
         <source>Project file to work on.</source>
         <translation>Fichier du projet sur lequel travailler.</translation>
     </message>
